Package com.volcengine.ark.model
Enum ListModelCustomizationJobsRequest.SortByEnum
- java.lang.Object
-
- java.lang.Enum<ListModelCustomizationJobsRequest.SortByEnum>
-
- com.volcengine.ark.model.ListModelCustomizationJobsRequest.SortByEnum
-
- All Implemented Interfaces:
Serializable,Comparable<ListModelCustomizationJobsRequest.SortByEnum>
- Enclosing class:
- ListModelCustomizationJobsRequest
public static enum ListModelCustomizationJobsRequest.SortByEnum extends Enum<ListModelCustomizationJobsRequest.SortByEnum>
Gets or Sets sortBy
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description static classListModelCustomizationJobsRequest.SortByEnum.Adapter
-
Enum Constant Summary
Enum Constants Enum Constant Description CREATETIME
-
Method Summary
All Methods Static Methods Instance Methods Concrete Methods Modifier and Type Method Description static ListModelCustomizationJobsRequest.SortByEnumfromValue(String input)StringgetValue()StringtoString()static ListModelCustomizationJobsRequest.SortByEnumvalueOf(String name)Returns the enum constant of this type with the specified name.static ListModelCustomizationJobsRequest.SortByEnum[]values()Returns an array containing the constants of this enum type, in the order they are declared.
-
-
-
Enum Constant Detail
-
CREATETIME
@SerializedName("CreateTime") public static final ListModelCustomizationJobsRequest.SortByEnum CREATETIME
-
-
Method Detail
-
values
public static ListModelCustomizationJobsRequest.SortByEnum[] values()
Returns an array containing the constants of this enum type, in the order they are declared. This method may be used to iterate over the constants as follows:for (ListModelCustomizationJobsRequest.SortByEnum c : ListModelCustomizationJobsRequest.SortByEnum.values()) System.out.println(c);
- Returns:
- an array containing the constants of this enum type, in the order they are declared
-
valueOf
public static ListModelCustomizationJobsRequest.SortByEnum valueOf(String name)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)- Parameters:
name- the name of the enum constant to be returned.- Returns:
- the enum constant with the specified name
- Throws:
IllegalArgumentException- if this enum type has no constant with the specified nameNullPointerException- if the argument is null
-
getValue
public String getValue()
-
toString
public String toString()
- Overrides:
toStringin classEnum<ListModelCustomizationJobsRequest.SortByEnum>
-
fromValue
public static ListModelCustomizationJobsRequest.SortByEnum fromValue(String input)
-
-