Package com.volcengine.ark.model
Enum ListModelCustomizationJobsRequest.SortOrderEnum
- java.lang.Object
-
- java.lang.Enum<ListModelCustomizationJobsRequest.SortOrderEnum>
-
- com.volcengine.ark.model.ListModelCustomizationJobsRequest.SortOrderEnum
-
- All Implemented Interfaces:
Serializable,Comparable<ListModelCustomizationJobsRequest.SortOrderEnum>
- Enclosing class:
- ListModelCustomizationJobsRequest
public static enum ListModelCustomizationJobsRequest.SortOrderEnum extends Enum<ListModelCustomizationJobsRequest.SortOrderEnum>
Gets or Sets sortOrder
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description static classListModelCustomizationJobsRequest.SortOrderEnum.Adapter
-
Method Summary
All Methods Static Methods Instance Methods Concrete Methods Modifier and Type Method Description static ListModelCustomizationJobsRequest.SortOrderEnumfromValue(String input)StringgetValue()StringtoString()static ListModelCustomizationJobsRequest.SortOrderEnumvalueOf(String name)Returns the enum constant of this type with the specified name.static ListModelCustomizationJobsRequest.SortOrderEnum[]values()Returns an array containing the constants of this enum type, in the order they are declared.
-
-
-
Enum Constant Detail
-
DESC
@SerializedName("Desc") public static final ListModelCustomizationJobsRequest.SortOrderEnum DESC
-
ASC
@SerializedName("Asc") public static final ListModelCustomizationJobsRequest.SortOrderEnum ASC
-
-
Method Detail
-
values
public static ListModelCustomizationJobsRequest.SortOrderEnum[] values()
Returns an array containing the constants of this enum type, in the order they are declared. This method may be used to iterate over the constants as follows:for (ListModelCustomizationJobsRequest.SortOrderEnum c : ListModelCustomizationJobsRequest.SortOrderEnum.values()) System.out.println(c);
- Returns:
- an array containing the constants of this enum type, in the order they are declared
-
valueOf
public static ListModelCustomizationJobsRequest.SortOrderEnum valueOf(String name)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)- Parameters:
name- the name of the enum constant to be returned.- Returns:
- the enum constant with the specified name
- Throws:
IllegalArgumentException- if this enum type has no constant with the specified nameNullPointerException- if the argument is null
-
getValue
public String getValue()
-
toString
public String toString()
- Overrides:
toStringin classEnum<ListModelCustomizationJobsRequest.SortOrderEnum>
-
fromValue
public static ListModelCustomizationJobsRequest.SortOrderEnum fromValue(String input)
-
-